@@ -3,8 +3,17 @@
 Pub/Sub requires a message broker object in the "broker" app key
 """
 from .broker import Broker, LocalBroker
+from .channel import Channel
 from .channels import Channels
 from .path import Sockets, WsPathMixin
 from .rpc import ws_rpc
 
-__all__ = ["Channels", "Broker", "WsPathMixin", "Sockets", "LocalBroker", "ws_rpc"]
+__all__ = [
+    "Channel",
+    "Channels",
+    "Broker",
+    "WsPathMixin",
+    "Sockets",
+    "LocalBroker",
+    "ws_rpc",
+]
